@@ -27,11 +27,9 @@ from rlax._src.distributions import categorical_kl_divergence
 from rlax._src.distributions import categorical_sample
 from rlax._src.distributions import clipped_entropy_softmax
 from rlax._src.distributions import epsilon_greedy
-from rlax._src.distributions import epsilon_softmax
 from rlax._src.distributions import gaussian_diagonal
 from rlax._src.distributions import greedy
 from rlax._src.distributions import multivariate_normal_kl_divergence
-from rlax._src.distributions import safe_epsilon_softmax
 from rlax._src.distributions import softmax
 from rlax._src.distributions import squashed_gaussian
 from rlax._src.embedding import embed_oar
@@ -90,6 +88,10 @@ from rlax._src.policy_gradients import policy_gradient_loss
 from rlax._src.policy_gradients import qpg_loss
 from rlax._src.policy_gradients import rm_loss
 from rlax._src.policy_gradients import rpg_loss
+from rlax._src.policy_targets import constant_policy_targets
+from rlax._src.policy_targets import PolicyTarget
+from rlax._src.policy_targets import sampled_policy_distillation_loss
+from rlax._src.policy_targets import zero_policy_targets
 from rlax._src.pop_art import art
 from rlax._src.pop_art import normalize
 from rlax._src.pop_art import pop
@@ -107,6 +109,8 @@ from rlax._src.transforms import signed_logp1
 from rlax._src.transforms import signed_parabolic
 from rlax._src.transforms import transform_from_2hot
 from rlax._src.transforms import transform_to_2hot
+from rlax._src.tree_util import transpose_first_axis_to_last
+from rlax._src.tree_util import transpose_last_axis_to_first
 from rlax._src.tree_util import tree_fn
 from rlax._src.tree_util import tree_map_zipped
 from rlax._src.tree_util import tree_replace_masked
@@ -138,7 +142,7 @@ from rlax._src.vtrace import leaky_vtrace_td_error_and_advantage
 from rlax._src.vtrace import vtrace
 from rlax._src.vtrace import vtrace_td_error_and_advantage
 
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 
 __all__ = (
     "add_gaussian_noise",
@@ -157,6 +161,7 @@ __all__ = (
     "clipped_surrogate_pg_loss",
     "compose_tx",
     "conditional_update",
+    "constant_policy_targets",
     "create_ema",
     "discounted_returns",
     "DISCOUNT_TRANSFORM_PAIR",
@@ -167,7 +172,6 @@ __all__ = (
     "entropy_loss",
     "episodic_memory_intrinsic_rewards",
     "epsilon_greedy",
-    "epsilon_softmax",
     "expected_sarsa",
     "expectile_loss",
     "extract_subsequences",
@@ -205,6 +209,7 @@ __all__ = (
     "periodic_update",
     "persistent_q_learning",
     "pixel_control_rewards",
+    "PolicyTarget",
     "policy_gradient_loss",
     "pop",
     "popart",
@@ -224,6 +229,7 @@ __all__ = (
     "rm_loss",
     "rpg_loss",
     "sample_start_indices",
+    "sampled_policy_distillation_loss",
     "sarsa",
     "sarsa_lambda",
     "sigmoid",
@@ -244,6 +250,8 @@ __all__ = (
     "transformed_retrace",
     "transform_from_2hot",
     "transform_to_2hot",
+    "transpose_last_axis_to_first",
+    "transpose_first_axis_to_last",
     "tree_fn",
     "tree_map_zipped",
     "tree_replace_masked",
@@ -260,6 +268,7 @@ __all__ = (
     "vmpo_loss",
     "vtrace",
     "vtrace_td_error_and_advantage",
+    "zero_policy_targets",
 )
 
 #  _________________________________________
